import logging
import logging.config
import os
from logging import Logger as ILogger

from singleton import Singleton


class Logger(ILogger, metaclass=Singleton):
    """ Логгер """
    LOGGING_CONFIG_OBJECT = {
        "version": 1,
        "disable_existing_loggers": False,
        "formatters": {
            "standard": {
                "format": "%(asctime)s %(levelname)-7s %(message)s %(module)s(%(lineno)s)",
            }
        },
        "handlers": {
            "default": {
                "class": "logging.handlers.WatchedFileHandler",
                "level": "DEBUG",
                "formatter": "standard",
                "filename": "/linuxcash/logs/current/servicestub.log"
            }
        },
        "loggers": {
            "": {
                "handlers": ["default"],
                "level": "DEBUG",
                "propagate": False
            }
        }
    }

    def __new__(cls, *args, **kwargs):
        super(Logger, cls).__new__(cls, *args, **kwargs)
        os.makedirs('/linuxcash/logs/current/', exist_ok=True)
        logging.config.dictConfig(cls.LOGGING_CONFIG_OBJECT)
        return logging.getLogger('root')
