from aiohttp import web

from singleton import Singleton
from services.basicservice import BasicService


class Certificate(BasicService, metaclass=Singleton):
    def __init__(self):
        super().__init__(__file__)
        self._loadCases('certificate.json')

    def getRoutes(self) -> list[web.AbstractRouteDef]:
        return [web.get('/ACC/rest/v1/cards/{certificateNumber}', handler=self.certificateByNumber),
                web.post('/ACC/rest/v1/assets', handler=self.transaction),
                web.put('/ACC/rest/v1/assets/{sessionId}/rollback', handler=self.transactionRollback)]

    async def certificateByNumber(self, request: web.Request) -> web.Response:
        self.log.info(f"Запрос данных о карте по номеру карты: '{request.match_info['certificateNumber']}'")
        return self._createResponse(request.path if self._hasCases(request.path) else '/ACC/rest/v1/cards/<certificateNumber>')

    async def transaction(self, request: web.Request) -> web.Response:
        self.log.info(f"Создание транзакции по оплате: данные транзакции: '{request.query_string}'")
        return self._createResponse(request.path if self._hasCases(request.path) else '/ACC/rest/v1/assets<transactionData>')

    async def transactionRollback(self, request: web.Request) -> web.Response:
        self.log.info(f"Создание транзакции отмены оплаты: информация о сессии: '{request.match_info['sessionId']}', данные транзакции: '{request.query_string}'")
        return self._createResponse(request.path if self._hasCases(request.path) else '/ACC/rest/v1/assets/<sessionId>/rollback<transactionData>')


instance = Certificate()
