import json
import os
from configparser import ConfigParser
from aiohttp import web

from services.basicservice import BasicService
from singleton import Singleton


class DeferredCheck(BasicService, metaclass=Singleton):
    checkStatus = False

    def __init__(self):
        super().__init__(__file__)
        conf = ConfigParser()
        conf.read(os.path.join(self.serviceDir, 'config.ini'))
        if conf.has_option('DeferredCheck', 'checkStatus'):
            self.checkStatus = conf.getboolean('DeferredCheck', 'checkStatus')
        self._loadCases('cases.json')

    
    def getRoutes(self) -> list[web.AbstractRouteDef]:
        return [web.post('/CSrest/rest/dictionaries/pendingchecks', handler=self.addCheck),
                web.get('/CSrest/rest/dictionaries/pendingchecks/{checkId:(?!bypage).+}', handler=self.getCheck),
                web.put('/CSrest/rest/dictionaries/pendingchecks/{checkId}', handler=self.updateCheck),
                web.get('/CSrest/rest/dictionaries/pendingchecks/bypage', handler=self.getChecks)]
        
    async def addCheck(self, request: web.Request) -> web.Response:
        self.log.info('Добавление отложенного чека')        
        return self._createResponse(request.path)

    async def getCheck(self, request: web.Request) -> web.Response:
        self.log.info(f'Получение отложенного чека: {request.match_info["checkId"]}')
        return self._createResponse(
                request.path if self._hasCases(request.path) else '/CSrest/rest/dictionaries/pendingchecks/<checkId>',
                request.method)
    
    async def updateCheck(self, request: web.Request) -> web.Response:
        self.log.info(f'Обновление отложенного чека: {request.match_info["checkId"]}')
        return self._createResponse(
                request.path if self._hasCases(request.path) else '/CSrest/rest/dictionaries/pendingchecks/<checkId>',
                request.method)
    
    async def getChecks(self, request: web.Request) -> web.Response:
        response = self._createResponse(request.path)
        if self.checkStatus:
            data = json.loads(response.text)
            states = request.query.getall("states")
            self.log.info(f'Получение списка отложенных чеков со статусами "{", ".join(states)}"')
            content = []
            num = 0

            for deferredCheck in data["content"]:
                if deferredCheck['state'] in states:
                    content.append(deferredCheck)
                    num = num + 1

            data['content'] = content
            data['totalElements'] = num
            data['numberOfElements'] = num
            response.text = json.dumps(data)
        else:
            self.log.info('Получение списка отложенных чеков')

        return response


instance = DeferredCheck()
