import os
from aiohttp import web

from services.basicservice import BasicService
from singleton import Singleton
from configparser import ConfigParser


class Kaspi(BasicService, metaclass=Singleton):
    def __init__(self):
        super().__init__(__file__)
        self._loadCases('cases.json')
        conf = ConfigParser()
        conf.read(os.path.join(self.serviceDir, 'config.ini'))
        self.servicePath = conf.get('kaspi', 'path') if conf.has_option('kaspi', 'path') else '/kaspi'
    
    def getRoutes(self) -> list[web.AbstractRouteDef]:
        return [web.get(os.path.join(self.servicePath, '{operation:payment|refund|status}'), handler=self.reqV1),
                web.get(os.path.join(self.servicePath, 'v2/{operation:payment|refund|status|actualize}'), handler=self.reqV2),]
    
    async def reqV1(self, request: web.Request) -> web.Response:
        self.log.info(f"Протокол версии: 1; Операция: {request.match_info['operation']}")
        return self._createResponse(request.match_info['operation'])
    
    async def reqV2(self, request: web.Request) -> web.Response:
        self.log.info(f"Протокол версии: 2; Операция: {request.match_info['operation']}")
        return self._createResponse(request.path)

instance = Kaspi()
