import os
from configparser import ConfigParser
from aiohttp import web

from services.basicservice import BasicService
from singleton import Singleton


class Mfg(BasicService, metaclass=Singleton):
    def __init__(self):
        super().__init__(__file__)
        conf = ConfigParser()
        conf.read(os.path.join(self.serviceDir, 'config.ini'))
        self.servicePath = conf.get('mfg', 'path') if conf.has_option('mfg', 'path') else '/api/ax/xpp/v1'
        self._loadCases('cases.json')

    def getRoutes(self) -> list[web.AbstractRouteDef]:
        return [web.get(os.path.join(self.servicePath, 'searchCustomer'), handler=self.searchCustomer),
                web.get(os.path.join(self.servicePath, 'cardInfo'), handler=self.cardInfo),
                web.get(os.path.join(self.servicePath, 'loyaltyBalanceInfo'), handler=self.loyaltyBalanceInfo),
                web.post(os.path.join(self.servicePath, 'calculateOrder'), handler=self.calculateOrder),
                web.post(os.path.join(self.servicePath, 'createOrder'), handler=self.createOrder),
                web.post(os.path.join(self.servicePath, 'updateOrder'), handler=self.updateOrder),
                web.post(os.path.join(self.servicePath, 'postOrder'), handler=self.postOrder),
                web.post(os.path.join(self.servicePath, 'cancelOrder'), handler=self.cancelOrder),
                web.post(os.path.join(self.servicePath, 'send'), handler=self.verification)]

    async def searchCustomer(self, request: web.Request) -> web.Response:
        self.log.info('Поиск клиента по набору параметров')
        return self._createResponse(request.path)

    async def cardInfo(self, request: web.Request) -> web.Response:
        self.log.info('Получение информации о карте')
        return self._createResponse(request.path)

    async def loyaltyBalanceInfo(self, request: web.Request) -> web.Response:
        self.log.info('Получение баллов для списания')
        return self._createResponse(request.path)

    async def calculateOrder(self, request: web.Request) -> web.Response:
        self.log.info('Метод предварительного расчёта баллов')
        return self._createResponse(request.path)

    async def createOrder(self, request: web.Request) -> web.Response:
        self.log.info('Метод создания заказа')
        return self._createResponse(request.path)

    async def updateOrder(self, request: web.Request) -> web.Response:
        self.log.info('Метод обновления заказа')
        return self._createResponse(request.path)

    async def postOrder(self, request: web.Request) -> web.Response:
        self.log.info('Метод оплаты заказа')
        return self._createResponse(request.path)

    async def cancelOrder(self, request: web.Request) -> web.Response:
        self.log.info('Метод для полной отмены заказа')
        return self._createResponse(request.path)

    async def verification(self, request: web.Request) -> web.Response:
        self.log.info('Метод верификации по СМС')
        return self._createResponse(request.path)


instance = Mfg()
