import os
from aiohttp import web

from singleton import Singleton
from services.basicservice import BasicService


class Mobile(BasicService, metaclass=Singleton):
    def __init__(self):
        super().__init__(__file__)
        self._loadAllCases()

    def getRoutes(self) -> list[web.AbstractRouteDef]:
        return [web.post('/mobile/client', handler=self.client),
                web.post('/mobile/client/balance', handler=self.balance),
                web.post('/mobile/client/modify', handler=self.modify),
                web.post('/mobile/client/registration', handler=self.clientRegistration),

                web.post('/mobile/feed', handler=self.feed),
                web.static('/mobile/static/images', os.path.join(self.serviceDir, 'images'), show_index=True),

                web.post('/mobile/bonushistory', handler=self.bonusHistory),
                web.post('/mobile/purchasehistory', handler=self.purchaseHistory),
                web.post('/mobile/check', handler=self.check),

                web.post('/mobile/verification/request', handler=self.verificationRequest),
                web.post('/mobile/verification/verify', handler=self.verificationVerify),

                web.post('/mobile/catalog/goods', handler=self.goods),
                web.post('/mobile/catalog', handler=self.catalog)]

    async def client(self, request: web.Request) -> web.Response:
        phone = (await request.json()).get('phone')
        self.log.info(f'Запрос списка карт по номеру телефона {phone}')
        return self._createResponse(request.path, phone if self._hasCases(request.path, phone) else "notfound")

    async def balance(self, request: web.Request) -> web.Response:
        self.log.info('Запрос расширенного баланса по карте')
        return self._createResponse(request.path)
    
    async def modify(self, request: web.Request) -> web.Response:
        self.log.info('Запрос расширенного баланса по карте')
        return self._createResponse(request.path)

    async def clientRegistration(self, request: web.Request) -> web.Response:
        self.log.info('Регистрация клиента')
        return self._createResponse(request.path)

    async def feed(self, request: web.Request) -> web.Response:
        self.log.info(f'Получение ленты для номера {request.query.get("phone")}')
        return self._createResponse(request.path)

    async def bonusHistory(self, request: web.Request) -> web.Response:
        self.log.info('Получение истории бонусных операций')
        return self._createResponse(request.path)

    async def purchaseHistory(self, request: web.Request) -> web.Response:
        self.log.info('Получение истории покупок')
        return self._createResponse(request.path)

    async def check(self, request: web.Request) -> web.Response:
        self.log.info('Получение чека')
        return self._createResponse(request.path)

    async def verificationRequest(self, request: web.Request) -> web.Response:
        self.log.info(f'Запрос кода подтверждения для телефона {request.query.get("phone")}')
        return self._createResponse(request.path)

    async def verificationVerify(self, request: web.Request) -> web.Response:
        payload = await request.json()
        code = payload.get('code')
        self.log.info(f'Проверка кода {code} для телефона {payload.get("phone")}')
        return self._createResponse(request.path, code if self._hasCases(request.path, code) else "incorrectcode")

    async def goods(self, request: web.Request) -> web.Response:
        id = (await request.json()).get('id')
        self.log.info(f'Получение информации о товаре {id}')
        return self._createResponse(request.path, id if self._hasCases(request.path, id) else "notfound")

    async def catalog(self, request: web.Request) -> web.Response:
        id = (await request.json()).get('id')
        self.log.info(f'Получение информации о каталоге {id}')
        return self._createResponse(request.path, id if self._hasCases(request.path, id) else "notfound")


instance = Mobile()
