from aiohttp import web

from singleton import Singleton
from services.basicservice import BasicService


class OnlineCards(BasicService, metaclass=Singleton):
    def __init__(self):
        super().__init__(__file__)
        self._loadCases('onlinecards.json')

    def getRoutes(self) -> list[web.AbstractRouteDef]:
        return [web.get('/onlinecards/number/{cardNumber}', handler=self.cardByNumber),
                web.get('/v1/cards/number/{cardNumber}', handler=self.cardByNumber),
                web.get('/onlinecards/phonenumber/{phoneNumber}', handler=self.cardByPhone),
                web.get('/v1/cards/phonenumber/{phoneNumber}', handler=self.cardByPhone),
                web.get('/onlinecards/list/by/phonenumber/{phoneNumber}', handler=self.cardsByPhone)]

    async def cardByNumber(self, request: web.Request) -> web.Response:
        self.log.info(f"Запрос данных о карте по номеру карты: '{request.match_info['cardNumber']}'")
        return self._createResponse(request.path if self._hasCases(request.path) else '/onlinecards/number/<cardNumber>')

    async def cardByPhone(self, request: web.Request) -> web.Response:
        self.log.info(f"Запрос данных о карте по номеру телефона: '{request.match_info['phoneNumber']}'")
        return self._createResponse(request.path if self._hasCases(request.path) else '/onlinecards/phonenumber/<phoneNumber>')

    async def cardsByPhone(self, request: web.Request) -> web.Response:
        self.log.info(f"Запрос списка номеров карт по номеру телефона: '{request.match_info['phoneNumber']}'")
        return self._createResponse(request.path if self._hasCases(request.path) else '/onlinecards/list/by/phonenumber/<phoneNumber>')


instance = OnlineCards()
