from aiohttp import web

from services.basicservice import BasicService
from singleton import Singleton


class Oplati(BasicService, metaclass=Singleton):
    def __init__(self):
        super().__init__(__file__)
        self._loadCases('oplati.json')

    def getRoutes(self) -> list[web.AbstractRouteDef]:
        return [web.get('/tokens', handler=self.getToken),
                web.post('/pos/demandPayment', handler=self.demandPayment),
                web.get('/pos/consumerStatus', handler=self.consumerStatus),
                web.post('/pos/async/payments', handler=self.asyncPayments),
                web.delete('/pos/payments/{orderNumber}', handler=self.deleteByOrderNumber),
                web.post('/pos/payments/{orderNumber}/reversals', handler=self.reversalByOrderNumber)]

    async def getToken(self, request: web.Request) -> web.Response:
        self.log.info("Получение токена")
        return self._createResponse(request.path)

    async def demandPayment(self, request: web.Request) -> web.Response:
        self.log.info("Требование оплаты")
        return self._createResponse(request.path)

    async def consumerStatus(self, request: web.Request) -> web.Response:
        self.log.info("Получение сведений о готовности клиента")
        return self._createResponse(request.path)

    async def asyncPayments(self, request: web.Request) -> web.Response:
        self.log.info("Отправить запрос на осуществление платежа (с ожиданием)")
        return self._createResponse(request.path)

    async def deleteByOrderNumber(self, request: web.Request) -> web.Response:
        self.log.info(f"Техническая отмена последней операции: '{request.match_info['orderNumber']}'")
        return self._createResponse(request.path if self._hasCases(request.path) else '/pos/payments/<orderNumber>')

    async def reversalByOrderNumber(self, request: web.Request) -> web.Response:
        self.log.info(f"Отмена операции: '{request.match_info['orderNumber']}'")
        return self._createResponse(request.path if self._hasCases(request.path) else '/pos/payments/<orderNumber>/reversals')


instance = Oplati()
