from aiohttp import web

from services.basicservice import BasicService
from singleton import Singleton


class Podeli(BasicService, metaclass=Singleton):
    def __init__(self):
        super().__init__(__file__)
        self._loadCases('podeli.json')

    def getRoutes(self) -> list[web.AbstractRouteDef]:
        return [web.post('/create', handler=self.create),
                web.post('/create_offline', handler=self.create_offline),
                web.get('/{orderId}/info', handler=self.info),
                web.post('/{orderId}/commit', handler=self.commit),
                web.post('/{orderId}/cancel', handler=self.cancel),
                web.post('/{orderId}/refund', handler=self.refund)]

    async def create(self, request: web.Request) -> web.Response:
        self.log.info("Выбор способа оплаты")
        return self._createResponse(request.path)

    async def create_offline(self, request: web.Request) -> web.Response:
        self.log.info("Создание заказа оффлайн")
        return self._createResponse(request.path)

    async def info(self, request: web.Request) -> web.Response:
        self.log.info(f"Получение информации по заказу '{request.match_info['orderId']}'")
        return self._createResponse(request.path if self._hasCases(request.path) else '/<orderId>/info')

    async def commit(self, request: web.Request) -> web.Response:
        self.log.info(f"Подтверждение заказа '{request.match_info['orderId']}'")
        return self._createResponse(request.path if self._hasCases(request.path) else '/<orderId>/commit')

    async def cancel(self, request: web.Request) -> web.Response:
        self.log.info(f"Отмены заказа '{request.match_info['orderId']}'")
        return self._createResponse(request.path if self._hasCases(request.path) else '/<orderId>/cancel')

    async def refund(self, request: web.Request) -> web.Response:
        self.log.info(f"Возврат товара по заказу '{request.match_info['orderId']}'")
        return self._createResponse(request.path if self._hasCases(request.path) else '/<orderId>/refund')


instance = Podeli()
