from aiohttp import web
import xml.etree.ElementTree as ET

from services.basicservice import BasicService
from singleton import Singleton


class WinelabCertificate(BasicService, metaclass=Singleton):
    def __init__(self):
        super().__init__(__file__)
        self._loadCases('cases.json')

    def getRoutes(self) -> list[web.AbstractRouteDef]:
        return [web.post('/winelabCertificate', handler=self.handler)]

    async def handler(self, request: web.Request) -> web.Response:
        root = ET.fromstring(await request.text())
        action = "undefined"

        namespaces = {"soapenv": "http://schemas.xmlsoap.org/soap/envelope/",
                      "ser": "http://services.processing.cards.crystals.ru/"}
        if root.find(".//ser:getPresentCardInformation", namespaces):
            action = "getPresentCardInformation"
        elif root.find(".//ser:activatePresentCard", namespaces):
            action = "activatePresentCard"
        elif root.find(".//ser:deActivatePresentCard", namespaces):
            action = "deactivatePresentCard"
        elif root.find(".//ser:paymentPresentCard", namespaces):
            action = "paymentPresentCard"
        elif root.find(".//ser:undoUsePresentCard", namespaces):
            action = "undoUsePresentCard"
 
        self.log.info(f"Действие: {action}")
        response = self._createResponse(action)
        self.log.info(f"Ответ : {response.text}")
        return response

instance = WinelabCertificate()
