#!/usr/bin/env python3

from aiohttp import web
from configparser import ConfigParser
from logger import Logger
import importlib
import os
import sys


class ServiceStub(web.Application):
    def __init__(self):
        super(ServiceStub, self).__init__()
        self.log = Logger()
        conf = ConfigParser()
        conf.read(os.path.join(os.path.dirname(__file__), 'conf/config.ini'))
        self.host = conf.get('main', 'host') if conf.has_option('main', 'host') else '127.0.0.1'
        self.port = conf.getint('main', 'port') if conf.has_option('main', 'port') else 55555

        self.services = conf.get('main', 'services') if conf.has_option('main', 'services') else ''
        self.services = list(filter(None, map(lambda x: x.strip(), self.services.split(','))))


    def __del__(self):
        self.log.info("Остановка сервиса")


    def start(self) -> None:
        self.log.info('Загрузка модулей')

        routesCount = 0
        # загрузка сервисов.
        # TODO: Сделано на скорую руку, нужно переписать!!!
        for service in self.services:
            self.log.info(f"Обнаружен сервис {service}")
            try:
                module = importlib.import_module(f'services.{service}.{service}')
                self.log.debug(f'Регистрация сервиса {type(module.instance).__name__}')
                routes = module.instance.getRoutes()
                if len(routes) > 0:
                    for route in routes:
                        if isinstance(route, web.StaticDef):
                            self.log.info(f"\tРегистрация статического ресурса '{route.path}' по пути '{route.prefix}'")
                        elif isinstance(route, web.RouteDef):
                            self.log.info(f"\tРегистрация метода '{route.method}' по пути '{route.path}'")
                        else:
                            raise Exception(f"Неподдерживаемый тип маршрута {type(route)}")
                    self.add_routes(routes)
                    routesCount += len(routes)
            except Exception as e:
                self.log.error(f'Ошибка загрузки модуля {service}: {e}')

        if routesCount > 0:
            self.log.info(f'Запуск сервиса на {self.host}:{self.port}')
            web.run_app(self, host=self.host, port=self.port)
        else:
            msg = 'Не обнаружено ни одного сервиса'
            print(msg, file=sys.stderr)
            self.log.warning(msg)


if __name__ == '__main__':
    try:
        ServiceStub().start()
    except Exception as e:
        print(e)
